@@ -166,8 +166,8 @@ def ret_phone_number(elem):
 	return ret
 
 
-def get_properties():
-	ret = {
+def get_properties(elem):
+	function = {
 		"status" : ret_status,
 		"date" : ret_date,
 		"rich_text" : ret_rich_text,
@@ -186,4 +186,6 @@ def get_properties():
 		"last_edited_by" : ret_last_edited_by,
 		"formula" : ret_formula
 	}
+	print(elem)
+	ret = function[elem['type']](elem)
 	return ret
